(**************************************************************************)
(*  Lack - Package manager for non-root users                             *)
(*  (C) 2008 Olivier Schwander <olivier.schwander@ens-lyon.org>           *)
(*  http://chadok.info/lack                                               *)
(*                                                                        *)
(*  This file is part of Lack.                                            *)
(*                                                                        *)
(*  Lack is free software: you can redistribute it and/or modify          *)
(*  it under the terms of the GNU General Public License as published by  *)
(*  the Free Software Foundation, either version 3 of the License, or     *)
(*  (at your option) any later version.                                   *)
(*                                                                        *)
(*  Foobar is distributed in the hope that it will be useful,             *)
(*  but WITHOUT ANY WARRANTY; without even the implied warranty of        *)
(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *)
(*  GNU General Public License for more details.                          *)
(*                                                                        *)
(*  You should have received a copy of the GNU General Public License     *)
(*  along with Foobar.  If not, see <http://www.gnu.org/licenses/>.       *)
(*                                                                        *)
(**************************************************************************)

open Parameter

exception Invalid_file of string
exception File_not_found of string
exception Invalid_url
exception Missing of string

type version =
  | Exact of string
  | Minmax of string * string
  | List of string list

type dep_dsc = {
  dep_name: string;
  dep_altnames: (string * string) list;
  dep_version: version;
  dep_mandatory: bool;
  yes_imply: parameter list;
  no_imply: parameter list;
  required_paramaters: parameter list;
}

type dependency =
  | Pkg of dep_dsc

  | Or of dependency list

type package = {
  pkg_name : string;
  pkg_version: string;

  pkg_homepage: string option;
  pkg_licence: string option;
  pkg_maintainer: string option;
  pkg_maintainer_email: string option;

  pkg_url: string;
  pkg_directory: string;
  pkg_fetch_cmd: string;
  pkg_extract_cmd: string;
  pkg_digest: string option;

  pkg_patches: string list;

  pkg_depends: dependency list;

  pkg_conf_options: parameter list;
  pkg_conf_cmd: string;
  pkg_conf_prefix: parameter option;

  pkg_build_options: parameter list;
  pkg_build_cmd: string;
  pkg_build_prefix: parameter option;

  pkg_install_options: parameter list;
  pkg_install_cmd: string;
  pkg_install_prefix: parameter option;
}

val parse : bool -> string -> string -> package

