(**************************************************************************)
(*  Lack - Package manager for non-root users                             *)
(*  (C) 2008 Olivier Schwander <olivier.schwander@ens-lyon.org>           *)
(*  http://chadok.info/lack                                               *)
(*                                                                        *)
(*  This file is part of Lack.                                            *)
(*                                                                        *)
(*  Lack is free software: you can redistribute it and/or modify          *)
(*  it under the terms of the GNU General Public License as published by  *)
(*  the Free Software Foundation, either version 3 of the License, or     *)
(*  (at your option) any later version.                                   *)
(*                                                                        *)
(*  Foobar is distributed in the hope that it will be useful,             *)
(*  but WITHOUT ANY WARRANTY; without even the implied warranty of        *)
(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *)
(*  GNU General Public License for more details.                          *)
(*                                                                        *)
(*  You should have received a copy of the GNU General Public License     *)
(*  along with Foobar.  If not, see <http://www.gnu.org/licenses/>.       *)
(*                                                                        *)
(**************************************************************************)

type parameter =
  | Env of string * string
  | Arg of string

exception Not_PREFIX

(* for compatibility with packages without explicit $PREFIX *)
let prefixed = ref false

let build_args ?(configure=false) prefix params =
  let line = Buffer.create 32 in
  let add s = Buffer.add_substitute line
      (function "PREFIX" -> prefixed := true; prefix | _ -> raise Not_PREFIX) s in
  List.iter (function
          | Arg s -> add s
          | Env (s, v) -> failwith "Not implemented" (* Unix.putenv s v *)
  ) params;
  let line = Buffer.contents line in    
      (* if it is the configure steps, add "--prefix $PREFIX", see prefixed *)
      if configure && not !prefixed then
          line^" "^(Defaults.give "prefix")^" "^prefix
      else
          line

let build_prefix path name version =
  path^"/"^name^"/"^version

