(**************************************************************************)
(*  Lack - Package manager for non-root users                             *)
(*  (C) 2008 Olivier Schwander <olivier.schwander@ens-lyon.org>           *)
(*  http://chadok.info/lack                                               *)
(*                                                                        *)
(*  This file is part of Lack.                                            *)
(*                                                                        *)
(*  Lack is free software: you can redistribute it and/or modify          *)
(*  it under the terms of the GNU General Public License as published by  *)
(*  the Free Software Foundation, either version 3 of the License, or     *)
(*  (at your option) any later version.                                   *)
(*                                                                        *)
(*  Foobar is distributed in the hope that it will be useful,             *)
(*  but WITHOUT ANY WARRANTY; without even the implied warranty of        *)
(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *)
(*  GNU General Public License for more details.                          *)
(*                                                                        *)
(*  You should have received a copy of the GNU General Public License     *)
(*  along with Foobar.  If not, see <http://www.gnu.org/licenses/>.       *)
(*                                                                        *)
(**************************************************************************)

let command verbose cmd =
  let cmd = if verbose then cmd else cmd^" 1>/dev/null 2>&1" in
    if verbose then Printf.printf "$ %s\n" cmd;
    (Sys.command cmd) = 0

let mkdir d =
  ignore (command false ("mkdir -m 755 -p "^d))

let chdir = Sys.chdir

let some a =
  match a with
    | None -> raise Not_found
    | Some a -> a

let temp_dir () =
  let tmp = Filename.temp_file "lack_" "" in
    Sys.remove tmp;
    mkdir tmp;
    tmp

let substitute f s =
  let b = Buffer.create 0 in
    Buffer.add_substitute b f s;
    Buffer.contents b

let total l =
  fun x ->
    try List.assoc x l with
      | Not_found -> ""

let slurp cmd =
  let inchan = Unix.open_process_in cmd in
      input_line inchan

let chomp s =
  let n = String.length s in
    if s.[n-1] = '\n' then
      String.sub s 0 (n-2)
    else
      s

